pub struct RDescription {Show 22 fields
pub name: String,
pub description: String,
pub title: String,
pub maintainer: Option<String>,
pub author: Option<String>,
pub authors: Option<RCode>,
pub version: Version,
pub encoding: Option<String>,
pub license: String,
pub url: Option<Vec<UrlEntry>>,
pub bug_reports: Option<String>,
pub imports: Option<Relations>,
pub suggests: Option<Relations>,
pub depends: Option<Relations>,
pub linking_to: Option<Relations>,
pub lazy_data: Option<String>,
pub collate: Option<String>,
pub vignette_builder: Option<String>,
pub system_requirements: Option<String>,
pub date: Option<String>,
pub language: Option<String>,
pub repository: Option<String>,
}Expand description
A DESCRIPTION file.
Fields
name: StringThe name of the package.
description: StringA short description of the package.
title: StringThe title of the package.
maintainer: Option<String>The maintainer of the package.
Who wrote the the package
‘Authors@R’ is a special field that can contain R code that is evaluated to get the authors and maintainers.
version: VersionThe version of the package.
encoding: Option<String>If the DESCRIPTION file is not written in pure ASCII, the encoding field must be used to specify the encoding.
license: StringThe license of the package.
url: Option<Vec<UrlEntry>>URLs related to the package.
bug_reports: Option<String>The URL or email address where bug reports should be sent.
imports: Option<Relations>The packages that this package depends on.
suggests: Option<Relations>The packages that this package suggests.
depends: Option<Relations>The packages that this package depends on.
linking_to: Option<Relations>The packages that this package links to.
lazy_data: Option<String>Whether the package has lazy data.
collate: Option<String>The order in which R scripts are loaded.
vignette_builder: Option<String>The package used to build vignettes.
system_requirements: Option<String>The system requirements for the package.
date: Option<String>The release date of the current version of the package. Strongly recommended to use the ISO 8601 format: YYYY-MM-DD
language: Option<String>Indicates the package documentation is not in English. This should be a comma-separated list of IETF language tags as defined by RFC5646
repository: Option<String>The R Repository to use for this package. E.g. “CRAN” or “Bioconductor”